AsyncScheduler class

Asynchronous scheduler that keeps track of pending actions manually.

Inheritance
Implementers

Constructors

AsyncScheduler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasPending → bool
Returns true, if there are actions pending.
no setter
now → DateTime
Returns the current time.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduled → SplayTreeMap<DateTime, List<SchedulerAction>>
Sorted list of pending actions.
final

Methods

flush() → void
Performs all the eligible pending actions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schedule(Callback0 callback) → Disposable
Schedules a callback to be executed.
override
scheduleAbsolute(DateTime dateTime, Callback0 callback) → Disposable
Schedules a callback to be executed at the specified dateTime.
override
scheduleIteration(Predicate0 callback) → Disposable
Schedules a callback to be executed while its return value is true.
override
schedulePeriodic(Duration duration, Callback1<Disposable> callback) → Disposable
Schedules a callback to be executed periodically every duration.
override
scheduleRelative(Duration duration, Callback0 callback) → Disposable
Schedules a callback to be executed after the specified duration.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited